## Dropdowns

All India | All India (divider) | Sales (split) | Kandivalli (Dark blue)
--- | --- | --- | ---
Action Another action Something else here | Action Another action Something else here | Action Another action Something else here Separated link | Action Another action Something else here

{% apply view_source %}

Print sequence | Rajan
Action Another action Something else here | Action Another action Something else here

{% end %}